@@ -96,7 +96,7 @@ def main():
     else:
         url = args.url_or_id
 
-    download(
+    filename = download(
         url=url,
         output=args.output,
         quiet=args.quiet,
@@ -105,6 +105,9 @@ def main():
         use_cookies=not args.no_cookies,
     )
 
+    if filename is None:
+        sys.exit(1)
+
 
 if __name__ == "__main__":
     main()
